@@ -50,13 +50,18 @@
 
 class QWidget;
 class QStyleOption;
+class QStyle;
+
+namespace Kirigami {
+    class PlatformTheme;
+}
 
 class QQuickTableRowImageProvider1 : public QQuickImageProvider
 {
 public:
     QQuickTableRowImageProvider1()
         : QQuickImageProvider(QQuickImageProvider::Pixmap) {}
-    QPixmap requestPixmap(const QString &id, QSize *size, const QSize &requestedSize);
+    QPixmap requestPixmap(const QString &id, QSize *size, const QSize &requestedSize) override;
 };
 
 class KQuickStyleItem: public QQuickItem
@@ -78,7 +83,7 @@ class KQuickStyleItem: public QQuickItem
     Q_PROPERTY( QString elementType READ elementType WRITE setElementType NOTIFY elementTypeChanged)
     Q_PROPERTY( QString text READ text WRITE setText NOTIFY textChanged)
     Q_PROPERTY( QString activeControl READ activeControl WRITE setActiveControl NOTIFY activeControlChanged)
-    Q_PROPERTY( QString style READ style NOTIFY styleChanged)
+    Q_PROPERTY( QString styleName READ styleName NOTIFY styleNameChanged)
     Q_PROPERTY( QVariantMap hints READ hints WRITE setHints NOTIFY hintChanged RESET resetHints)
     Q_PROPERTY( QVariantMap properties READ properties WRITE setProperties NOTIFY propertiesChanged)
     Q_PROPERTY( QFont font READ font NOTIFY fontChanged)
@@ -96,13 +101,18 @@ class KQuickStyleItem: public QQuickItem
     Q_PROPERTY( int textureWidth READ textureWidth WRITE setTextureWidth NOTIFY textureWidthChanged)
     Q_PROPERTY( int textureHeight READ textureHeight WRITE setTextureHeight NOTIFY textureHeightChanged)
 
+    Q_PROPERTY( int leftPadding READ leftPadding NOTIFY leftPaddingChanged)
+    Q_PROPERTY( int topPadding READ topPadding NOTIFY topPaddingChanged)
+    Q_PROPERTY( int rightPadding READ rightPadding NOTIFY rightPaddingChanged)
+    Q_PROPERTY( int bottomPadding READ bottomPadding NOTIFY bottomPaddingChanged)
+
     Q_PROPERTY( QQuickItem *control READ control WRITE setControl NOTIFY controlChanged)
 
     KQuickPadding* border() { return &m_border; }
 
 public:
-    KQuickStyleItem(QQuickItem *parent = 0);
-    ~KQuickStyleItem();
+    KQuickStyleItem(QQuickItem *parent = nullptr);
+    ~KQuickStyleItem() override;
 
     enum MenuItemType {
         SeparatorType = 0,
@@ -171,7 +181,7 @@ public:
     QVariantMap hints() const { return m_hints; }
     QVariantMap properties() const { return m_properties; }
     QFont font() const { return m_font;}
-    QString style() const;
+    QString styleName() const;
 
     void setSunken(bool sunken) { if (m_sunken != sunken) {m_sunken = sunken; emit sunkenChanged();}}
     void setRaised(bool raised) { if (m_raised!= raised) {m_raised = raised; emit raisedChanged();}}
@@ -203,6 +213,11 @@ public:
     virtual void initStyleOption ();
     void resolvePalette();
 
+    int leftPadding() const;
+    int topPadding() const;
+    int rightPadding() const;
+    int bottomPadding() const;
+
     Q_INVOKABLE qreal textWidth(const QString &);
     Q_INVOKABLE qreal textHeight(const QString &);
 
@@ -215,6 +230,8 @@ public:
     QQuickItem *control() const;
     void setControl(QQuickItem *control);
 
+    static QStyle *style();
+
 public Q_SLOTS:
     int pixelMetric(const QString&);
     QVariant styleHint(const QString&);
@@ -245,7 +262,7 @@ Q_SIGNALS:
     void valueChanged();
     void activeControlChanged();
     void infoChanged();
-    void styleChanged();
+    void styleNameChanged();
     void paintMarginsChanged();
     void hintChanged();
     void propertiesChanged();
@@ -258,20 +275,28 @@ Q_SIGNALS:
     void textureWidthChanged(int w);
     void textureHeightChanged(int h);
 
+    void leftPaddingChanged();
+    void topPaddingChanged();
+    void rightPaddingChanged();
+    void bottomPaddingChanged();
+
 protected:
-    virtual bool event(QEvent *);
-    virtual QSGNode *updatePaintNode(QSGNode *, UpdatePaintNodeData *);
-    virtual void updatePolish();
+    bool event(QEvent *) override;
+    QSGNode *updatePaintNode(QSGNode *, UpdatePaintNodeData *) override;
+    void updatePolish() override;
     bool eventFilter(QObject *watched, QEvent *event) override;
 
 private:
     const char* classNameForItem() const;
     QSize sizeFromContents(int width, int height);
     qreal baselineOffset();
+    void styleChanged();
 
 protected:
+    Kirigami::PlatformTheme *m_theme = nullptr;
     QStyleOption *m_styleoption;
     QPointer<QQuickItem> m_control;
+    QPointer<QWindow> m_window;
     Type m_itemType;
 
     QString m_type;
@@ -308,6 +333,8 @@ protected:
 
     QImage m_image;
     KQuickPadding m_border;
+
+    static QStyle *s_style;
 };
 
 
